@@ -57,7 +57,13 @@ def request_day_data_paquet(url, me_ts, ssj):
         print('no data')
     return dataframe
 
-def fetch_equity_daily_data(ticker=None, provider = 'yahoo', starting_date=None,running_date=None,local_root_directory=None):
+def save_equity_daily_data(data_df = None, ticker=None, provider = 'napoleon', starting_date=None,running_date=None,local_root_directory=None):
+    filename = ticker + '_' + starting_date.strftime('%d_%b_%Y') + '_' + running_date.strftime(
+        '%d_%b_%Y') + '_daily_returns.pkl'
+    data_df.to_pickle(local_root_directory + filename)
+
+
+def fetch_equity_daily_data(data = None, ticker=None, provider = 'yahoo', starting_date=None,running_date=None,local_root_directory=None):
     yahoo_tickers_equivalents = {
         'SPX' : '^GSPC',
         'SX5E' : '^STOXX50E',
@@ -576,10 +582,10 @@ class NaPoleonXConnector(object):
 
         return df
 
-    def get_signal_dataframe(self, productCodes, minDate, maxDate):
+    def get_signal_dataframe(self, productCodes, minDate, maxDate, last_only = True):
         minTs = dt.strptime(minDate, '%Y-%m-%d').strftime('%Y-%m-%d') + 'T00:00:00'
         maxTs = dt.strptime(maxDate, '%Y-%m-%d').strftime('%Y-%m-%d') + 'T23:59:59'
-        signals_df = pd.DataFrame(self.get_signal_data(productCodes,  minTs, maxTs, True))
+        signals_df = pd.DataFrame(self.get_signal_data(productCodes,  minTs, maxTs, last_only))
         return signals_df
 
     def get_underlyings(self, productCode):
