@@ -25,7 +25,7 @@ def add_datepart(df, fldname, drop=True, time=False):
     if drop: df.drop(fldname, axis=1, inplace=True)
 
 
-def add_rebalancing_datepart(df, fldname,  rebalancing_method = 'monthly'):
+def add_rebalancing_datepart(df, fldname,  rebalancing_method = 'monthly', last = True):
     if fldname not in df.columns:
         df[fldname] = df.index
     "Helper function that adds columns relevant to a date."
@@ -51,11 +51,17 @@ def add_rebalancing_datepart(df, fldname,  rebalancing_method = 'monthly'):
     for n in attr: df[targ_pre + n] = getattr(fld.dt, n.lower())
 
     if rebalancing_method == 'monthly':
-        df['is_rebalancing'] = abs(df['Month'].diff().shift(-1).fillna(0.))>0
+        if last:
+            df['is_rebalancing'] = abs(df['Month'].diff().shift(-1).fillna(0.))>0
+        else:
+            df['is_rebalancing'] = abs(df['Month'].diff().fillna(0.))>0
         df.drop('Month', axis=1, inplace=True)
 
     elif rebalancing_method == 'weekly':
-        df['is_rebalancing'] = abs(df['Week'].diff().shift(-1).fillna(0.))>0
+        if last:
+            df['is_rebalancing'] = abs(df['Week'].diff().shift(-1).fillna(0.))>0
+        else:
+            df['is_rebalancing'] = abs(df['Week'].diff().fillna(0.))>0
         df.drop('Week', axis=1, inplace=True)
     else:
         raise Exception('not supported rebalancing frequency')
